@@ -1,6 +1,6 @@
 {
     'name': "Comunitats Energètiques customizations",
-    'version': '12.0.0.0.5',
+    'version': '12.0.0.0.6',
     'depends': [
         'base_rest_base_structure',
         'cooperator_website',
@@ -10,6 +10,7 @@
         'base_user_role',
         'auth_api_key',
         'crm',
+        'community_maps',
     ],
     'author': "Coopdevs Treball SCCL & Som Energia SCCL",
     'website': 'https://somenergia.coop',
@@ -29,6 +30,7 @@
         'data/res_company_data.xml',
         'data/utm_data.xml',
         'data/crm_lead_tag.xml',
+        'data/crm_maps_data.xml',
         'views/res_config_settings.xml',
         'views/crm_lead_views.xml',
         'views/auth_oauth_provider_views.xml',
@@ -38,6 +40,7 @@
         'views/utm_views.xml',
         'views/menus.xml',
         'views/res_users.xml',
+        'views/cm_place.xml',
     ],
     'installable': True,
     'application': True,
