@@ -1,5 +1,5 @@
 from . import schemas
-from . import set_perms_service
+from . import ce_member_service
 from . import crm_lead_service
 from . import ce_member_profile_service
 from . import ce_community_service
